==> haskell-postgresql-binary-0.12.1.2-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.12.1.2
id: postgresql-binary-0.12.1.2-EXifzcuc8GG8yPP4qZ0Eeb
key: postgresql-binary-0.12.1.2-EXifzcuc8GG8yPP4qZ0Eeb
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
abi: 8ad0a274d0cbfea17c63e60bd2d7e185
exposed: True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding
hidden-modules: PostgreSQL.Binary.Encoding.Builders
                PostgreSQL.Binary.Prelude PostgreSQL.Binary.Integral
                PostgreSQL.Binary.Interval PostgreSQL.Binary.Numeric
                PostgreSQL.Binary.Time PostgreSQL.Binary.Inet
                PostgreSQL.Binary.BuilderPrim
import-dirs: /usr/lib/ghc-8.6.5/site-local/postgresql-binary-0.12.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/postgresql-binary-0.12.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/postgresql-binary-0.12.1.2
hs-libraries: HSpostgresql-binary-0.12.1.2-EXifzcuc8GG8yPP4qZ0Eeb
depends:
    aeson-1.4.3.0-AyEaiR0tyNR44JmKj60DSr base-4.12.0.0
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    binary-parser-0.5.5-8FV9WLyPomf73wodYxApuZ bytestring-0.10.8.2
    bytestring-strict-builder-0.4.5.1-kxaFXH8zEZ4z5HJZwsk0B
    containers-0.6.0.1 loch-th-0.2.2-3CPdVoaGmAI4E58ziaHpq7
    network-ip-0.3.0.2-2O9tlVgkU1pCW6j1OYeFPP
    placeholders-0.1-BvqrCQDGi4R6ufjrVRZiOw
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    uuid-1.3.13-8JD8aeFgvIZ76tj03ZzkIs
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-binary-0.12.1.2-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.12.1.2
id: postgresql-binary-0.12.1.2-CfqNCMroXiyIV4UtLqBkzI
key: postgresql-binary-0.12.1.2-CfqNCMroXiyIV4UtLqBkzI
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
abi: 35be79d8080415a1f16f398252cae320
exposed: True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding
hidden-modules: PostgreSQL.Binary.Encoding.Builders
                PostgreSQL.Binary.Prelude PostgreSQL.Binary.Integral
                PostgreSQL.Binary.Interval PostgreSQL.Binary.Numeric
                PostgreSQL.Binary.Time PostgreSQL.Binary.Inet
                PostgreSQL.Binary.BuilderPrim
import-dirs: /usr/lib/ghc-8.6.5/site-local/postgresql-binary-0.12.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/postgresql-binary-0.12.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/postgresql-binary-0.12.1.2
hs-libraries: HSpostgresql-binary-0.12.1.2-CfqNCMroXiyIV4UtLqBkzI
depends:
    aeson-1.4.3.0-2f2DWYxbnUnFm9iFQHaKmb base-4.12.0.0
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    binary-parser-0.5.5-8FV9WLyPomf73wodYxApuZ bytestring-0.10.8.2
    bytestring-strict-builder-0.4.5.1-DxqVR8zqV4bH4WtGmEDLch
    containers-0.6.0.1 loch-th-0.2.2-3CPdVoaGmAI4E58ziaHpq7
    network-ip-0.3.0.2-1tlConVhgHc7HnrgKjRXb3
    placeholders-0.1-BvqrCQDGi4R6ufjrVRZiOw
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    uuid-1.3.13-8JD8aeFgvIZ76tj03ZzkIs
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
